pub struct FmfSource { /* private fields */ }Trait Implementations
Sourceimpl FrameDataSource for FmfSource
impl FrameDataSource for FmfSource
Sourcefn frame0_time(&self) -> Option<DateTime<FixedOffset>>
fn frame0_time(&self) -> Option<DateTime<FixedOffset>>
Get the timestamp of the first frame. Read more
Sourcefn skip_n_frames(&mut self, n_frames: usize) -> Result<()>
fn skip_n_frames(&mut self, n_frames: usize) -> Result<()>
Set source to skip the first N frames. Read more
Sourcefn estimate_luminance_range(&mut self) -> Result<(u16, u16)>
fn estimate_luminance_range(&mut self) -> Result<(u16, u16)>
Scan over the input images and estimate the luminance range Read more
Sourcefn decode_order_iter(&mut self) -> Box<dyn Iterator<Item = Result<FrameData>>>
fn decode_order_iter(&mut self) -> Box<dyn Iterator<Item = Result<FrameData>>>
Get an iterator over all frames in decode order (the order samples
are stored in the stream). Read more
Sourcefn timestamp_source(&self) -> &str
fn timestamp_source(&self) -> &str
A string describing the source of the timestamp data
Sourcefn has_timestamps(&self) -> bool
fn has_timestamps(&self) -> bool
Whether timestamps are available. Read more
fn camera_name(&self) -> Option<&str>
fn gamma(&self) -> Option<f32>
Sourcefn srt_truncation(&self) -> Option<SrtTruncation>
fn srt_truncation(&self) -> Option<SrtTruncation>
Set when an SRT-file timestamp source ran out of usable stanzas
before covering every frame in the container, in which case the
source was truncated to the last complete group of pictures a stanza
is available for every frame of.
None for sources not using an SRT
file, or when the SRT covered every frame.Auto Trait Implementations
impl Freeze for FmfSource
impl RefUnwindSafe for FmfSource
impl Send for FmfSource
impl Sync for FmfSource
impl Unpin for FmfSource
impl UnsafeUnpin for FmfSource
impl UnwindSafe for FmfSource